#!/usr/bin/env python3
''' User Control Codes retrieved from:
    Supplement 1 Consumer Electronics Control (CEC)
    https://storage.googleapis.com/google-code-archive-downloads/v2/code.google.com/xtreamerdev/CEC_Specs.pdf
'''

USER_CONTROL_CODES = {
    0x00: 'Select',
    0x01: 'Up',
    0x02: 'Down',
    0x03: 'Left',
    0x04: 'Right',
    0x05: 'Right-Up',
    0x06: 'Right-Down',
    0x07: 'Left-Up',
    0x08: 'Left-Down',
    0x09: 'Root Menu',
    0x0a: 'Setup Menu',
    0x0b: 'Contents Menu',
    0x0c: 'Favorite Menu',
    0x0d: 'Exit',
    **dict.fromkeys(list(range(0x0e, 0x20)), 'Reserved'),
    **dict(enumerate([str(x) for x in range(10)], 0x20)),
    0x2a: 'Dot',
    0x2b: 'Enter',
    0x2c: 'Clear',
    **dict.fromkeys(list(range(0x2d, 0x2f)), 'Reserved'),
    0x2f: 'Next Favorite',
    0x30: 'Channel Up',
    0x31: 'Channel Down',
    0x32: 'Previous Channel',
    0x33: 'Sound Select',
    0x34: 'Input Select',
    0x35: 'Display Information',
    0x36: 'Help',
    0x37: 'Page Up',
    0x38: 'Page Down',
    **dict.fromkeys(list(range(0x39, 0x40)), 'Reserved'),
    0x40: 'Power',
    0x41: 'Volume Up',
    0x42: 'Volume Down',
    0x43: 'Mute',
    0x44: 'Play',
    0x45: 'Stop',
    0x46: 'Pause',
    0x47: 'Record',
    0x48: 'Rewind',
    0x49: 'Fast Forward',
    0x4a: 'Eject',
    0x4b: 'Forward',
    0x4c: 'Backward',
    0x4d: 'Stop-Record',
    0x4e: 'Pause-Record',
    0x4f: 'Reserved',
    0x50: 'Angle',
    0x51: 'Sub picture',
    0x52: 'Video on Demand',
    0x53: 'Electronic Program Guide',
    0x54: 'Timer Programming',
    0x55: 'Initial Configuration',
    **dict.fromkeys(list(range(0x56, 0x60)), 'Reserved'),
    0x60: 'Play Function',
    0x61: 'Pause-Play Function',
    0x62: 'Record Function',
    0x63: 'Pause-Record Function',
    0x64: 'Stop Function',
    0x65: 'Mute Function',
    0x66: 'Restore Volume Function',
    0x67: 'Tune Function',
    0x68: 'Select Media Function',
    0x69: 'Select A/V Input Function',
    0x6a: 'Select Audio Input Function',
    0x6b: 'Power Toggle Function',
    0x6c: 'Power Off Function',
    0x6d: 'Power On Function',
    **dict.fromkeys(list(range(0x6e, 0x71)), 'Reserved'),
    0x71: 'F1 (Blue)',
    0x72: 'F2 (Red)',
    0x73: 'F3 (Green)',
    0x74: 'F4 (Yellow)',
    0x75: 'F5',
    0x76: 'Data',
    **dict.fromkeys(list(range(0x77, 0x100)), 'Reserved'),
}

COMMANDS = {
    0x36: 'standby',
    0x80: 'wake',
}

DEFAULT_TV_CONFIG = {
    'name': 'CECDAEMON',
}

DEFAULT_REMOTE_CONFIG = {
    '0': 'KEY_ENTER',
    '1': 'KEY_UP',
    '2': 'KEY_DOWN',
    '3': 'KEY_LEFT',
    '4': 'KEY_RIGHT',
    '9': 'KEY_ESC',
    '10': 'KEY_C',
    '13': 'KEY_BACKSPACE',
    '32': 'KEY_0',
    '33': 'KEY_1',
    '34': 'KEY_2',
    '35': 'KEY_3',
    '36': 'KEY_4',
    '37': 'KEY_5',
    '38': 'KEY_6',
    '39': 'KEY_7',
    '40': 'KEY_8',
    '41': 'KEY_9',
    '42': 'KEY_DOT',
    '43': 'KEY_ENTER',
    '68': 'KEY_PLAY',
    '69': 'KEY_X',
    '70': 'KEY_PAUSE',
    '75': 'KEY_FASTFORWARD',
    '76': 'KEY_REWIND',
    '81': 'KEY_T',
    '113': 'KEY_BLUE',
    '114': 'KEY_RED',
    '115': 'KEY_GREEN',
    '116': 'KEY_YELLOW',
}

if __name__ == '__main__':
    import json
    print(json.dumps(USER_CONTROL_CODES, indent=4))
    print(json.dumps(COMMANDS, indent=4))
    print(json.dumps(DEFAULT_TV_CONFIG, indent=4))
    print(json.dumps(DEFAULT_REMOTE_CONFIG, indent=4))
